==> faxtomail-service-1.0-sources.jar: com/franciaflex/faxtomail/services/service/UserServiceImpl.java <==
package com.franciaflex.faxtomail.services.service;

/*
 * #%L
 * FaxToMail :: Service
 * $Id: UserServiceImpl.java 660 2014-10-02 11:30:33Z kmorin $
 * $HeadURL: http://svn.codelutin.com/faxtomail/tags/faxtomail-1.0/faxtomail-service/src/main/java/com/franciaflex/faxtomail/services/service/UserServiceImpl.java $
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.util.List;

import org.hibernate.Hibernate;

import com.franciaflex.faxtomail.persistence.entities.FaxToMailUser;
import com.franciaflex.faxtomail.persistence.entities.FaxToMailUserGroup;
import com.franciaflex.faxtomail.persistence.entities.FaxToMailUserGroupTopiaDao;
import com.franciaflex.faxtomail.persistence.entities.FaxToMailUserTopiaDao;
import com.franciaflex.faxtomail.services.FaxToMailServiceSupport;

/**
 * @author kmorin - kmorin@codelutin.com
 */
public class UserServiceImpl extends FaxToMailServiceSupport implements UserService {

    /**
     * Retourne le nombre d'utilisateur en base.
     * 
     * @return user count
     */
    @Override
    public long getActiveUserCount() {
        FaxToMailUserTopiaDao faxtomailUserDao = getPersistenceContext().getFaxToMailUserDao();
        long result = faxtomailUserDao.forHiddenEquals(false).count();
        return result;
    }

    /**
     * Retourne le nombre de groupe en base.
     * 
     * @return group count
     */
    @Override
    public long getActiveGroupCount() {
        FaxToMailUserGroupTopiaDao faxtomailUserGroupDao = getPersistenceContext().getFaxToMailUserGroupDao();
        long result = faxtomailUserGroupDao.forHiddenEquals(false).count();
        return result;
    }

    @Override
    public List<FaxToMailUser> getAllActiveUsers() {
        FaxToMailUserTopiaDao dao = getPersistenceContext().getFaxToMailUserDao();
        return dao.forHiddenEquals(false).setOrderByArguments(FaxToMailUser.PROPERTY_FIRST_NAME, FaxToMailUser.PROPERTY_LAST_NAME).findAll();
    }

    @Override
    public FaxToMailUser getUserByLogin(String login) {
        FaxToMailUserTopiaDao dao = getPersistenceContext().getFaxToMailUserDao();
        FaxToMailUser user = dao.forLoginEquals(login)
                                    .findUnique();
        return user;
    }

    @Override
    public List<FaxToMailUserGroup> getAllActiveUserGroups() {
        FaxToMailUserGroupTopiaDao dao = getPersistenceContext().getFaxToMailUserGroupDao();
        return dao.forHiddenEquals(false).setOrderByArguments(FaxToMailUserGroup.PROPERTY_COMPLETE_NAME).findAll();
    }

    @Override
    public FaxToMailUser getUser(String topiaId) {
        FaxToMailUserTopiaDao dao = getPersistenceContext().getFaxToMailUserDao();
        FaxToMailUser user = dao.forTopiaIdEquals(topiaId)
                                /*.addAllFetches(FaxToMailUser.PROPERTY_AFFECTED_FOLDERS)*/
                                .findUnique();
        Hibernate.initialize(user.getAffectedFolders());
        return user;
    }
}

==> faxtomail-service-1.1.6-sources.jar: com/franciaflex/faxtomail/services/service/UserServiceImpl.java <==
package com.franciaflex.faxtomail.services.service;

/*
 * #%L
 * FaxToMail :: Service
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.persistence.entities.FaxToMailUser;
import com.franciaflex.faxtomail.persistence.entities.FaxToMailUserGroup;
import com.franciaflex.faxtomail.persistence.entities.FaxToMailUserGroupTopiaDao;
import com.franciaflex.faxtomail.persistence.entities.FaxToMailUserTopiaDao;
import com.franciaflex.faxtomail.services.FaxToMailServiceSupport;
import org.hibernate.Hibernate;

import java.util.List;

/**
 * @author kmorin - kmorin@codelutin.com
 */
public class UserServiceImpl extends FaxToMailServiceSupport implements UserService {

    /**
     * Retourne le nombre d'utilisateur en base.
     * 
     * @return user count
     */
    @Override
    public long getActiveUserCount() {
        FaxToMailUserTopiaDao faxtomailUserDao = getPersistenceContext().getFaxToMailUserDao();
        long result = faxtomailUserDao.forHiddenEquals(false).count();
        return result;
    }

    /**
     * Retourne le nombre de groupe en base.
     * 
     * @return group count
     */
    @Override
    public long getActiveGroupCount() {
        FaxToMailUserGroupTopiaDao faxtomailUserGroupDao = getPersistenceContext().getFaxToMailUserGroupDao();
        long result = faxtomailUserGroupDao.forHiddenEquals(false).count();
        return result;
    }

    @Override
    public List<FaxToMailUser> getAllActiveUsers() {
        FaxToMailUserTopiaDao dao = getPersistenceContext().getFaxToMailUserDao();
        return dao.forHiddenEquals(false).setOrderByArguments(FaxToMailUser.PROPERTY_FIRST_NAME, FaxToMailUser.PROPERTY_LAST_NAME).findAll();
    }

    @Override
    public FaxToMailUser getUserByLogin(String login) {
        FaxToMailUserTopiaDao dao = getPersistenceContext().getFaxToMailUserDao();
        FaxToMailUser user = dao.forLoginEquals(login)
                                    .findUnique();
        return user;
    }

    @Override
    public List<FaxToMailUserGroup> getAllActiveUserGroups() {
        FaxToMailUserGroupTopiaDao dao = getPersistenceContext().getFaxToMailUserGroupDao();
        return dao.forHiddenEquals(false).setOrderByArguments(FaxToMailUserGroup.PROPERTY_COMPLETE_NAME).findAll();
    }

    @Override
    public FaxToMailUser getUser(String topiaId) {
        FaxToMailUserTopiaDao dao = getPersistenceContext().getFaxToMailUserDao();
        FaxToMailUser user = dao.forTopiaIdEquals(topiaId)
                                /*.addAllFetches(FaxToMailUser.PROPERTY_AFFECTED_FOLDERS)*/
                                .findUnique();
        Hibernate.initialize(user.getAffectedFolders());
        return user;
    }
}
